==> v4.3.3.tar.gz: omegat-4.3.3/src/org/omegat/gui/issues/IIssues.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool
          with fuzzy matching, translation memory, keyword search,
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2016 Aaron Madlon-Kay
               Home page: http://www.omegat.org/
               Support center: http://groups.yahoo.com/group/OmegaT/

 This file is part of OmegaT.

 OmegaT is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 OmegaT is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

package org.omegat.gui.issues;

/**
 * The interface exposing issue-displaying functionality to the rest of the
 * program.
 *
 * @author Aaron Madlon-Kay
 *
 */
public interface IIssues {

    void showAll();

    void showAll(String instructions);

    void showForFiles(String filePattern);

    void showForFiles(String filePattern, String instructions);

    void showForFiles(String filePattern, int jumpToEntry);

}

==> v5.7.1.tar.gz: omegat-5.7.1/src/org/omegat/gui/issues/IIssues.java <==
/**************************************************************************
 OmegaT - Computer Assisted Translation (CAT) tool
          with fuzzy matching, translation memory, keyword search,
          glossaries, and translation leveraging into updated projects.

 Copyright (C) 2016 Aaron Madlon-Kay
               Home page: http://www.omegat.org/
               Support center: https://omegat.org/support

 This file is part of OmegaT.

 OmegaT is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 OmegaT is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 **************************************************************************/

package org.omegat.gui.issues;

/**
 * The interface exposing issue-displaying functionality to the rest of the
 * program.
 *
 * @author Aaron Madlon-Kay
 *
 */
public interface IIssues {

    void showAll();

    void showAll(String instructions);

    void showForFiles(String filePattern);

    void showForFiles(String filePattern, String instructions);

    void showForFiles(String filePattern, int jumpToEntry);

}
